/*
	Advanved Dialogs v1.0.7
	Copyright (C) 2005-2008 Jonas Gehring

	Advanced Dialogs is free software; you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Advanced Dialogs is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// C Source File
// Created 29.08.2005; 23:03:04


#include <extgraph.h>							// ExtGraph by TI-Chess Team

#include "AdvDialogs.h"							// This should be obvious ;)
#include "Internal.h"							// This header should not be included in programs using Advanced Dialogs


#ifndef OSdequeue
#define OSdequeue _rom_call(short,(__pushort,void*),3AA)
#endif


// Clears the keyboard queue
void ClearKbdQueue(void)
{
	while (_rowread(0)) continue;
}


// Waits for a keypress and stores it in key
void GetKey(void *kbq, short *key)
{
	// Wait for keypress and mask out key repitition
	while (OSdequeue(key, kbq)) continue;
	*key &= 0xF7FF;
}


// Draws a colored string (black or white)
void GrayDrawColorString(short x, short y, const char *str, uchar color, uchar mode)
{
	if (color == COLOR_WHITE)
	{	
		GraySetAMSPlane(LIGHT_PLANE);
		DrawStr((mode == TXT_CENTERED ? (LCD_WIDTH - DrawStrWidth(str, F_4x6)) >> 1 : x), y, str, A_XOR);
	}
	else
	{
		GrayDrawStrExt(x, y, str, A_NORMAL | (mode == TXT_CENTERED ? A_CENTERED : 0), F_4x6);
	}
}


// Save grayscale screen contents
void SaveScreen(void)
{
	if (tscr == NULL)
	{
		// Allocate space for the LCD buffers
		if ((tscr = malloc(sizeof(LCD_BUFFER)*2)) == NULL)
		{
			return;
		}
		
		// Save contents
		FastCopyScreen_R(GrayGetPlane(LIGHT_PLANE), tscr);
		FastCopyScreen_R(GrayGetPlane(DARK_PLANE), tscr+sizeof(LCD_BUFFER));	
	}
}


// Restore grayscale screen contents
void RestoreScreen(void)
{
	if (tscr)
	{
		FastCopyScreen_R(tscr, GrayGetPlane(LIGHT_PLANE));
		FastCopyScreen_R(tscr+sizeof(LCD_BUFFER), GrayGetPlane(DARK_PLANE));
		free(tscr);
		tscr = NULL;
	}
}

